Method: CalculatorPackage::HttpClient#execute_as_binary
- Defined in:
- lib/calculator_package/http/http_client.rb
#execute_as_binary(_http_request) ⇒ Object
Execute an HttpRequest when the response is expected to be binary.
21 22 23 24 |
# File 'lib/calculator_package/http/http_client.rb', line 21 def execute_as_binary(_http_request) raise NotImplementedError, 'This method needs to be implemented in a child class.' end |